<?php # $Id: serendipity_lang_en.inc.php 568 2005-10-18 19:01:10Z garvinhicking $
# Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
# All rights reserved.  See LICENSE file for licensing details
# Arabic issue was translated by Way http://www.flyingway.com  cp1256
/* vim: set sts=4 ts=4 expandtab : */

@define('LANG_CHARSET', 'cp1256');
@define('DATE_LOCALES', 'Arabic,ar , ar_SA.windows-1256');
@define('DATE_FORMAT_ENTRY', '%A, %B %e. %Y');
@define('DATE_FORMAT_SHORT', '%Y-%m-%d %H:%M');
@define('WYSIWYG_LANG', 'en');
@define('NUMBER_FORMAT_DECIMALS', '2');
@define('NUMBER_FORMAT_DECPOINT', '.');
@define('NUMBER_FORMAT_THOUSANDS', ',');
@define('LANG_DIRECTION', 'rtl');

@define('SERENDIPITY_ADMIN_SUITE', '  ');
@define('HAVE_TO_BE_LOGGED_ON', '        ');
@define('WRONG_USERNAME_OR_PASSWORD', '      ');
@define('APPEARANCE', '');
@define('MANAGE_STYLES', ' ');
@define('CONFIGURE_PLUGINS', '   -  ');
@define('CONFIGURATION', '  ');
@define('BACK_TO_BLOG', '  ');
@define('LOGIN', ' ');
@define('LOGOUT', '');
@define('LOGGEDOUT', ' ');
@define('CREATE', '');
@define('SAVE', '');
@define('NAME', '');
@define('CREATE_NEW_CAT', '  ');
@define('I_WANT_THUMB', '     ');
@define('I_WANT_BIG_IMAGE', '     ');
@define('I_WANT_NO_LINK', '{    ');
@define('I_WANT_IT_TO_LINK', '       ');
@define('BACK', '');
@define('FORWARD', '');
@define('ANONYMOUS', '');
@define('NEW_TRACKBACK_TO', '     ');
@define('NEW_COMMENT_TO', '    ');
@define('RECENT', ' ...');
@define('OLDER', ' ...');
@define('DONE', ' ');
@define('WELCOME_BACK', '  ');
@define('TITLE', '');
@define('DESCRIPTION', '');
@define('PLACEMENT', '');
@define('DELETE', '');
@define('SAVE', '');
@define('UP', '');
@define('DOWN', '');
@define('ENTRIES', '');
@define('NEW_ENTRY', '  ');
@define('EDIT_ENTRIES', ' ');
@define('CATEGORIES', '');
@define('WARNING_THIS_BLAHBLAH', ":\\n             ");
@define('CREATE_THUMBS', '   ');
@define('MANAGE_IMAGES', ' ');
@define('NAME', '');
@define('EMAIL', ' ');
@define('HOMEPAGE', '   ');
@define('COMMENT', '');
@define('REMEMBER_INFO', ' ʿ ');
@define('SUBMIT_COMMENT', ' ');
@define('NO_ENTRIES_TO_PRINT', '   ');
@define('COMMENTS', '');
@define('ADD_COMMENT', ' ');
@define('NO_COMMENTS', ' ');
@define('POSTED_BY', ' ');
@define('ON', '');
@define('A_NEW_COMMENT_BLAHBLAH', '      "%s",    "%s".');
@define('A_NEW_TRACKBACK_BLAHBLAH', '       "%s".');
@define('NO_CATEGORY', '  ');
@define('ENTRY_BODY', '   ');
@define('EXTENDED_BODY', ' ');
@define('CATEGORY', '');
@define('EDIT', '');
@define('NO_ENTRIES_BLAHBLAH', '       %s' . "\n");
@define('YOUR_SEARCH_RETURNED_BLAHBLAH', '   %s  %s  ');
@define('SEARCH_TOO_SHORT', '        3  ! ! !     *       3       ');
@define('IMAGE', 'Image');
@define('ERROR_FILE_NOT_EXISTS', ':     ');
@define('ERROR_FILE_EXISTS', ' :        ');
@define('ERROR_SOMETHING', ':   ');
@define('ADDING_IMAGE', ' ...');
@define('THUMB_CREATED_DONE', ' <br/>');
@define('ERROR_FILE_EXISTS_ALREADY', '!   ');
@define('ERROR_UNKNOWN_NOUPLOAD', '   ! ! !                 ! ! !  ISP     php.ini     ');
@define('GO', '!');
@define('NEWSIZE', ' : ');
@define('RESIZE_BLAHBLAH', '<b>  %s</b>');
@define('ORIGINAL_SIZE', '  <i>%sx%s</i> pixel');
@define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>     -         -              Tab --        -           </p>');
@define('QUICKJUMP_CALENDAR', 'QuickJump Calendar');
@define('QUICKSEARCH', ' ');
@define('SEARCH_FOR_ENTRY', '   ');
@define('ARCHIVES', '');
@define('BROWSE_ARCHIVES', '  ');
@define('TOP_REFERRER', '  :');
@define('SHOWS_TOP_SITES', '    ');
@define('TOP_EXITS', ' ');
@define('SHOWS_TOP_EXIT', '       ');
@define('SYNDICATION', '');
@define('SHOWS_RSS_BLAHBLAH', '    RSS');
@define('ADVERTISES_BLAHBLAH', '   ');
@define('HTML_NUGGET', 'HTML Nugget');
@define('HOLDS_A_BLAHBLAH', '      ');
@define('TITLE_FOR_NUGGET', '  ');
@define('THE_NUGGET', '  HTML!');
@define('SYNDICATE_THIS_BLOG', '      ');
@define('YOU_CHOSE', ' %s');
@define('IMAGE_ROTATE_LEFT', '  90    ');
@define('IMAGE_ROTATE_RIGHT', '  90    ');
@define('IMAGE_SIZE', ' ');
@define('IMAGE_AS_A_LINK', ' ');
@define('POWERED_BY', '');
@define('TRACKBACKS', ' ');
@define('TRACKBACK', ' ');
@define('NO_TRACKBACKS', '   ');
@define('TOPICS_OF', ' ');
@define('VIEW_FULL', ' ');
@define('VIEW_TOPICS', ' ');
@define('AT', '');
@define('SET_AS_TEMPLATE', '   ');
@define('IN', '');
@define('EXCERPT', '');
@define('TRACKED', '');
@define('LINK_TO_ENTRY', '  ');
@define('LINK_TO_REMOTE_ENTRY', '   ');
@define('IP_ADDRESS', 'IP-address');
@define('USER', '');
@define('THUMBNAIL_USING_OWN', ' %s         ');
@define('THUMBNAIL_FAILED_COPY', '   %s     .     ');
@define('AUTHOR', '');
@define('LAST_UPDATED', ' ');
@define('TRACKBACK_SPECIFIC', '    ');
@define('DIRECT_LINK', '    ');
@define('COMMENT_ADDED', '    ');
@define('COMMENT_ADDED_CLICK', 'Click %shere to return%s to the comments, and %shere to close%s this window.');
@define('COMMENT_NOT_ADDED', '           ');
@define('COMMENT_NOT_ADDED_CLICK', 'Click %shere to return%s to the comments, and %shere to close%s this window.');
@define('COMMENTS_DISABLE', '     ');
@define('COMMENTS_ENABLE', '    ');
@define('COMMENTS_CLOSED', '       ');
@define('EMPTY_COMMENT', '        %s   %s    ');
@define('ENTRIES_FOR', '  %s');
@define('DOCUMENT_NOT_FOUND', '      %s');
@define('USERNAME', ' ');
@define('PASSWORD', ' ');
@define('AUTOMATIC_LOGIN', ' ');
@define('SERENDIPITY_INSTALLATION', '  ');
@define('LEFT', '');
@define('RIGHT', '');
@define('HIDDEN', '');
@define('REMOVE_TICKED_PLUGINS', '  ');
@define('SAVE_CHANGES_TO_LAYOUT', '   ');
@define('COMMENTS_FROM', ' ');
@define('ERROR', '');
@define('ENTRY_SAVED', '  ');
@define('DELETE_SURE', '     %s   -    ');
@define('NOT_REALLY', '');
@define('DUMP_IT', '');
@define('RIP_ENTRY', '  %s ');
@define('CATEGORY_DELETED_ARTICLES_MOVED', 'Category #%s deleted. Old articles moved to category #%s.');
@define('CATEGORY_DELETED', ' #%s  .');
@define('INVALID_CATEGORY', '      ');
@define('CATEGORY_SAVED', '  ');
@define('SELECT_TEMPLATE', '      ');
@define('ENTRIES_NOT_SUCCESSFULLY_INSERTED', '     ! ! !');
@define('MT_DATA_FILE', '   ');
@define('FORCE', '');
@define('CREATE_AUTHOR', '  \'%s\'.');
@define('CREATE_CATEGORY', '  \'%s\'.');
@define('MYSQL_REQUIRED', 'You must have the MySQL extension in order to perform this action.');
@define('COULDNT_CONNECT', '    : %s.');
@define('COULDNT_SELECT_DB', '     : %s.');
@define('COULDNT_SELECT_USER_INFO', '    : %s.');
@define('COULDNT_SELECT_CATEGORY_INFO', '    : %s.');
@define('COULDNT_SELECT_ENTRY_INFO', '    : %s.');
@define('COULDNT_SELECT_COMMENT_INFO', '    : %s.');
@define('YES', '');
@define('NO', '');
@define('USE_DEFAULT', '');
@define('CHECK_N_SAVE', '  ');
@define('DIRECTORY_WRITE_ERROR', '     %s    ');
@define('DIRECTORY_CREATE_ERROR', ' %s        ');
@define('DIRECTORY_RUN_CMD', '&nbsp;-&gt; run <i>%s %s</i>');
@define('CANT_EXECUTE_BINARY', 'Cannot execute the %s binary');
@define('FILE_WRITE_ERROR', 'Cannot write to file %s.');
@define('FILE_CREATE_YOURSELF', '          ');
@define('COPY_CODE_BELOW', '<br />*         %s  %s :<b><pre>%s</pre></b>' . "\n");
@define('WWW_USER', 'Change www to the user apache runs as (e.g. nobody).');
@define('BROWSER_RELOAD', 'Once you have done this, hit your browser\'s "reload" button.');
@define('DIAGNOSTIC_ERROR', '        :');
@define('SERENDIPITY_NOT_INSTALLED', 'Serendipity is not yet installed. Please <a href="%s">install</a> it now.');
@define('INCLUDE_ERROR', 'serendipity error: could not include %s - exiting.');
@define('DATABASE_ERROR', 'serendipity error: unable to connect to database - exiting.');
@define('CREATE_DATABASE', 'Creating default database setup...');
@define('ATTEMPT_WRITE_FILE', 'Attempting to write %s file...');
@define('WRITTEN_N_SAVED', '    ');
@define('IMAGE_ALIGNMENT', ' ');
@define('ENTER_NEW_NAME', '   : ');
@define('RESIZING', ' ');
@define('RESIZE_DONE', ' (  %s ).');
@define('SYNCING', '     ');
@define('SYNC_OPTION_LEGEND', 'Thumbnail Synchronization Options');
@define('SYNC_OPTION_KEEPTHUMBS', 'Keep all existing thumbnails');
@define('SYNC_OPTION_SIZECHECKTHUMBS', 'Keep existing thumbnails only if they are the correct size');
@define('SYNC_OPTION_DELETETHUMBS', 'Regenerate all thumbnails');
@define('SYNC_DONE', 'Done ( %s ).');
@define('FILE_NOT_FOUND', '    <b>%s</b>,      ݿ');
@define('ABORT_NOW', ' ');
@define('REMOTE_FILE_NOT_FOUND', 'File was not located on the remote server, are you sure the URL: <b>%s</b> is correct?');
@define('FILE_FETCHED', '%s fetched as %s');
@define('FILE_UPLOADED', ' %s     %s');
@define('WORD_OR', 'Or');
@define('SCALING_IMAGE', 'Scaling %s to %s x %s px');
@define('KEEP_PROPORTIONS', '   ');
@define('REALLY_SCALE_IMAGE', '       ! !  ! !      ');
@define('TOGGLE_ALL', '    ');
@define('TOGGLE_OPTION', 'Toggle option');
@define('SUBSCRIBE_TO_THIS_ENTRY', '   ');
@define('UNSUBSCRIBE_OK', "%s       ");
@define('NEW_COMMENT_TO_SUBSCRIBED_ENTRY', 'New comment to subscribed entry "%s"');
@define('SUBSCRIPTION_MAIL', "Hello %s,\n\nA new comment was made to the entry you are monitoring on \"%s\", entitled \"%s\"\nThe name of the poster is: %s\n\nYou can find the entry here: %s\n\nYou can unsubscribe by clicking on this link: %s\n");
@define('SUBSCRIPTION_TRACKBACK_MAIL', "Hello %s,\n\nA new trackback was added to the entry you are monitoring on \"%s\", entitled \"%s\"\nThe name of the poster is: %s\n\nYou can find the entry here: %s\n\nYou can unsubscribe by clicking on this link: %s\n");
@define('SIGNATURE', "\n-- \n%s is powered by Serendipity.\nThe best blog around, you can use it too.\nCheck out <http://s9y.org> to find out how.");
@define('SYNDICATION_PLUGIN_091', 'RSS 0.91 feed');
@define('SYNDICATION_PLUGIN_10', 'RSS 1.0 feed');
@define('SYNDICATION_PLUGIN_20', 'RSS 2.0 feed');
@define('SYNDICATION_PLUGIN_20c', 'RSS 2.0 comments');
@define('SYNDICATION_PLUGIN_ATOM03', 'ATOM 0.3 feed');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR', ' " "');
@define('SYNDICATION_PLUGIN_WEBMASTER',  ' " "');
@define('SYNDICATION_PLUGIN_BANNERURL', 'Image for the RSS feed');
@define('SYNDICATION_PLUGIN_BANNERWIDTH', ' ');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT', ' ');
@define('SYNDICATION_PLUGIN_WEBMASTER_DESC',  '    . (: ) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR_DESC', '     -        [RSS 2.0]');
@define('SYNDICATION_PLUGIN_BANNERURL_DESC', '    GIF/JPEG/PNG        -        ');
@define('SYNDICATION_PLUGIN_BANNERWIDTH_DESC', 'in pixels, max. 144');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT_DESC', 'in pixels, max. 400');
@define('SYNDICATION_PLUGIN_TTL', 'Field "ttl" (time-to-live)');
@define('SYNDICATION_PLUGIN_TTL_DESC', 'Amount of minutes after which your blog should not be cached any more by foreign sites/applications (empty: hidden) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_PUBDATE', '  ');
@define('SYNDICATION_PLUGIN_PUBDATE_DESC', 'Should the "pubDate"-field be embedded for a RSS-channel, to show the date of the latest entry?');
@define('CONTENT', '');
@define('TYPE', '');
@define('DRAFT', '');
@define('PUBLISH', '');
@define('PREVIEW', ' ');
@define('DATE', '');
@define('DATE_FORMAT_2', 'Y-m-d H:i'); // Needs to be ISO 8601 compliant for date conversion!
@define('DATE_INVALID', ':       ! !       YYYY-MM-DD HH:MM');
@define('CATEGORY_PLUGIN_DESC', '   ');
@define('ALL_AUTHORS', ' ');
@define('CATEGORIES_TO_FETCH', ' ');
@define('CATEGORIES_TO_FETCH_DESC', '     ȿ');
@define('PAGE_BROWSE_ENTRIES', '  %s  %s,  %s ');
@define('PREVIOUS_PAGE', ' ');
@define('NEXT_PAGE', ' ');
@define('ALL_CATEGORIES', ' ');
@define('DO_MARKUP', '  ');
@define('GENERAL_PLUGIN_DATEFORMAT', ' ');
@define('GENERAL_PLUGIN_DATEFORMAT_BLAHBLAH', '     PHPs strftime() variables. (Default: "%s")');
@define('ERROR_TEMPLATE_FILE', '     .   ');
@define('ADVANCED_OPTIONS', ' ');
@define('EDIT_ENTRY', ' ');
@define('HTACCESS_ERROR', 'To check your local webserver installation, serendipity needs to be able to write the file ".htaccess". This was not possible because of permission errors. Please adjust the permissions like this: <br />&nbsp;&nbsp;%s<br />and reload this page.');
@define('SIDEBAR_PLUGINS', '    ');
@define('EVENT_PLUGINS', '  ');
@define('SORT_ORDER', ' ');
@define('SORT_ORDER_NAME', ' ');
@define('SORT_ORDER_EXTENSION', ' ');
@define('SORT_ORDER_SIZE', ' ');
@define('SORT_ORDER_WIDTH', ' ');
@define('SORT_ORDER_HEIGHT', ' ');
@define('SORT_ORDER_DATE', ' ');
@define('SORT_ORDER_ASC', ' ');
@define('SORT_ORDER_DESC', ' ');
@define('THUMBNAIL_SHORT', ' ');
@define('ORIGINAL_SHORT', 'Orig.');
@define('APPLY_MARKUP_TO', '   %s');
@define('CALENDAR_BEGINNING_OF_WEEK', ' ');
@define('SERENDIPITY_NEEDS_UPGRADE', 'Serendipity has detected that your currently installed Serendipity version is %s. It seems you are attempting to upgrade to version %s, so you need to <a href="%s">click here</a> to continue the upgrade process.');
@define('SERENDIPITY_UPGRADER_WELCOME', 'Hi, and welcome to the Serendipity upgrade agent.');
@define('SERENDIPITY_UPGRADER_PURPOSE', 'I am here to help you upgrade your Serendipity %s installation.');
@define('SERENDIPITY_UPGRADER_WHY', 'You are seeing this message because you have just installed Serendipity %s, but have not yet upgraded your database installation to fit this version');
@define('SERENDIPITY_UPGRADER_DATABASE_UPDATES', 'Database updates (%s)');
@define('SERENDIPITY_UPGRADER_FOUND_SQL_FILES', 'I have found the following .sql files which needs to be run before you can continue normal operation of Serendipity');
@define('SERENDIPITY_UPGRADER_VERSION_SPECIFIC',  'Version specific tasks');
@define('SERENDIPITY_UPGRADER_NO_VERSION_SPECIFIC', 'No version specific tasks found');
@define('SERENDIPITY_UPGRADER_PROCEED_QUESTION', 'Do you wish me to perform the above tasks?');
@define('SERENDIPITY_UPGRADER_PROCEED_ABORT', 'No, I will run them manually');
@define('SERENDIPITY_UPGRADER_PROCEED_DOIT', 'Yes, please do so');
@define('SERENDIPITY_UPGRADER_NO_UPGRADES', 'It appears you do not need any upgrades run');
@define('SERENDIPITY_UPGRADER_CONSIDER_DONE', 'Consider Serendipity upgraded');
@define('SERENDIPITY_UPGRADER_YOU_HAVE_IGNORED', 'You have ignored the upgrade stage of Serendipity, please make sure your database is correctly installed, and scheduled functions are run');
@define('SERENDIPITY_UPGRADER_NOW_UPGRADED', 'Your Serendipity installation is now upgraded to version %s');
@define('SERENDIPITY_UPGRADER_RETURN_HERE', 'You can return to your blog by clicking %shere%s');
@define('MANAGE_USERS', ' ');
@define('CREATE_NEW_USER', '  ');
@define('CREATE_NOT_AUTHORIZED', '             ');
@define('CREATE_NOT_AUTHORIZED_USERLEVEL', '           ');
@define('CREATED_USER', '  %s  ');
@define('MODIFIED_USER', '     %s');
@define('USER_LEVEL', 'Userlevel');
@define('DELETE_USER', '       #%d %s             ! ! !    ');
@define('DELETED_USER', '  #%d %s  .');
@define('LIMIT_TO_NUMBER', '   ǿ');
@define('ENTRIES_PER_PAGE', '   ');
@define('XML_IMAGE_TO_DISPLAY', 'XML Button');
@define('XML_IMAGE_TO_DISPLAY_DESC','Links to XML Feeds will be displayed by this image. Leave empty for default, enter \'none\' to disable.');

@define('DIRECTORIES_AVAILABLE', '   .       ! !         ');
@define('ALL_DIRECTORIES', ' ');
@define('MANAGE_DIRECTORIES', ' ');
@define('DIRECTORY_CREATED', ' <strong>%s</strong>  ');
@define('PARENT_DIRECTORY', '   ');
@define('CONFIRM_DELETE_DIRECTORY', '         %s?');
@define('ERROR_NO_DIRECTORY', ':     %s ');
@define('CHECKING_DIRECTORY', '    %s ');
@define('DELETING_FILE', '  %s ...');
@define('ERROR_DIRECTORY_NOT_EMPTY', 'Could not remove non-empty directory. Check the "force deletion" checkbox if you want to remove those files as well, and then submit again. Existing files are:');
@define('DIRECTORY_DELETE_FAILED', 'Deletion of directory %s failed. Check permissions or messages above.');
@define('DIRECTORY_DELETE_SUCCESS', '   %s ');
@define('SKIPPING_FILE_EXTENSION', ' :     %s.');
@define('SKIPPING_FILE_UNREADABLE', ' : %s  ');
@define('FOUND_FILE', '      : %s');
@define('ALREADY_SUBCATEGORY', ' %s     %s');
@define('PARENT_CATEGORY', ' ');
@define('IN_REPLY_TO', '  ');
@define('TOP_LEVEL', ' ');
@define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s feed');
@define('PERMISSIONS', '');
@define('INTEGRITY', 'Verify Installation Integrity');
@define('CHECKSUMS_NOT_FOUND', 'Unable to compare checksums! (No checksums.inc.php in main directory)');
@define('CHECKSUMS_PASS', 'All required files verified.');
@define('CHECKSUM_FAILED', '%s corrupt or modified: failed verification');
@define('SETTINGS_SAVED_AT', '      %s');

/* DATABASE SETTINGS */
@define('INSTALL_CAT_DB', '  ');
@define('INSTALL_CAT_DB_DESC', '         .       ');
@define('INSTALL_DBTYPE', '  ');
@define('INSTALL_DBTYPE_DESC', '  ');
@define('INSTALL_DBHOST', '  ');
@define('INSTALL_DBHOST_DESC', '    ');
@define('INSTALL_DBUSER', '   ');
@define('INSTALL_DBUSER_DESC', '       ');
@define('INSTALL_DBPASS', '   ');
@define('INSTALL_DBPASS_DESC', '      ');
@define('INSTALL_DBNAME', '  ');
@define('INSTALL_DBNAME_DESC', '  ');
@define('INSTALL_DBPREFIX', '   ');
@define('INSTALL_DBPREFIX_DESC', '   - serendipity_');

/* PATHS */
@define('INSTALL_CAT_PATHS', '');
@define('INSTALL_CAT_PATHS_DESC', '          -      (/)    ');
@define('INSTALL_FULLPATH', ' ');
@define('INSTALL_FULLPATH_DESC', '      () ');
@define('INSTALL_UPLOADPATH', '  ');
@define('INSTALL_UPLOADPATH_DESC', '      , \'Full path\' - typically \'uploads/\'');
@define('INSTALL_RELPATH', '  ');
@define('INSTALL_RELPATH_DESC', ' :       , typically \'/serendipity/\'');
@define('INSTALL_RELTEMPLPATH', '   ');
@define('INSTALL_RELTEMPLPATH_DESC', 'The path to the folder containing your templates - Relative to the \'relative path\'');
@define('INSTALL_RELUPLOADPATH', '  ');
@define('INSTALL_RELUPLOADPATH_DESC', '        \'relative path\'');
@define('INSTALL_URL', ' ');
@define('INSTALL_URL_DESC', '     . ');
@define('INSTALL_INDEXFILE', 'Index file');
@define('INSTALL_INDEXFILE_DESC', '   ');

/* GENERAL SETTINGS */
@define('INSTALL_CAT_SETTINGS', ' ');
@define('INSTALL_CAT_SETTINGS_DESC', '  ');
@define('INSTALL_USERNAME', '  ');
@define('INSTALL_USERNAME_DESC', '  ');
@define('INSTALL_PASSWORD', '  ');
@define('INSTALL_PASSWORD_DESC', '  ');
@define('INSTALL_EMAIL', ' ');
@define('INSTALL_EMAIL_DESC', '   ');
@define('INSTALL_SENDMAIL', '    ');
@define('INSTALL_SENDMAIL_DESC', '          ߿  .  ');
@define('INSTALL_SUBSCRIBE', '    ڿ');
@define('INSTALL_SUBSCRIBE_DESC', '    .           ');
@define('INSTALL_BLOGNAME', ' ');
@define('INSTALL_BLOGNAME_DESC', ' ');
@define('INSTALL_BLOGDESC', ' ');
@define('INSTALL_BLOGDESC_DESC', '       ');
@define('INSTALL_LANG', '');
@define('INSTALL_LANG_DESC', '  ');

/* APPEARANCE AND OPTIONS    */
@define('INSTALL_CAT_DISPLAY', '  ');
@define('INSTALL_CAT_DISPLAY_DESC', '      ');
@define('INSTALL_WYSIWYG', '  ');
@define('INSTALL_WYSIWYG_DESC', '       ɿ       .     ');
@define('INSTALL_XHTML11', 'Force XHTML 1.1 compliance');
@define('INSTALL_XHTML11_DESC', 'Do you want to force XHTML 1.1 compliance (may cause problems for back-/frontend on older 4th generation browsers)');
@define('INSTALL_POPUP', '    ɿ');
@define('INSTALL_POPUP_DESC', '      ʡ    ǿ');
@define('INSTALL_EMBED', '     Ͽ');
@define('INSTALL_EMBED_DESC', '            ()         .                    .         ');
@define('INSTALL_TOP_AS_LINKS', 'Show Top Exits/Referrers as links?');
@define('INSTALL_TOP_AS_LINKS_DESC', '"no": Exits and Referrers are shown as plain text to prevent google spam. "yes": Exits and Referrers are shown as hyperlinks. "default": Use setting from global configuration (recommended).');
@define('INSTALL_BLOCKREF', 'Blocked Referers');
@define('INSTALL_BLOCKREF_DESC', 'Are there any special hosts you want not to show up in the referers list? Separate the list of hostnames with \';\' and note that the host is blocked by substring matches!');
@define('INSTALL_REWRITE', 'URL Rewriting');
@define('INSTALL_REWRITE_DESC', 'Select which rules you wish to use when generating URLs. Enabling rewrite rules will make pretty URLs for your blog and make it better indexable for spiders like google. The webserver needs to support either mod_rewrite or "AllowOverride All" for your serendipity dir. The default setting is auto-detected');

/* IMAGECONVERSION SETTINGS */
@define('INSTALL_CAT_IMAGECONV', '  ');
@define('INSTALL_CAT_IMAGECONV_DESC', '       ');
@define('INSTALL_IMAGEMAGICK', '  ');
@define('INSTALL_IMAGEMAGICK_DESC', '              ѿ');
@define('INSTALL_IMAGEMAGICKPATH', '  ');
@define('INSTALL_IMAGEMAGICKPATH_DESC', '          ');
@define('INSTALL_THUMBSUFFIX', '  ');
@define('INSTALL_THUMBSUFFIX_DESC', '      : original.[suffix].ext');
@define('INSTALL_THUMBWIDTH', '  ');
@define('INSTALL_THUMBWIDTH_DESC', '     ');
@define('INSTALL_THUMBDIM', 'Thumbnail constrained dimension');
@define('INSTALL_THUMBDIM_LARGEST', 'Largest');
@define('INSTALL_THUMBDIM_WIDTH', 'Width');
@define('INSTALL_THUMBDIM_HEIGHT', 'Height');
@define('INSTALL_THUMBDIM_DESC', 'Dimension to be constrained to the thumbnail max size. The default "' . 
    INSTALL_THUMBDIM_LARGEST .  '" limits both dimensions, so neither can be greater than the max size; "' . 
    INSTALL_THUMBDIM_WIDTH . '" and "' .  INSTALL_THUMBDIM_HEIGHT . 
    '" only limit the chosen dimension, so the other could be larger than the max size.');

/* Personal details */
@define('USERCONF_CAT_PERSONAL', '  ');
@define('USERCONF_CAT_PERSONAL_DESC', '   ');
@define('USERCONF_USERNAME', ' ');
@define('USERCONF_USERNAME_DESC', '     ');
@define('USERCONF_PASSWORD', '   ');
@define('USERCONF_PASSWORD_DESC', '       ');
@define('USERCONF_EMAIL', ' ');
@define('USERCONF_EMAIL_DESC', '       ');
@define('USERCONF_SENDCOMMENTS', '      ޿ ');
@define('USERCONF_SENDCOMMENTS_DESC', '          ߿  .  ');
@define('USERCONF_SENDTRACKBACKS', '   ȿ');
@define('USERCONF_SENDTRACKBACKS_DESC', '        ߿  ');
@define('USERCONF_ALLOWPUBLISH', ':  ڿ');
@define('USERCONF_ALLOWPUBLISH_DESC', '    ڿ');
@define('SUCCESS', '');
@define('POWERED_BY_SHOW_TEXT', '     ');
@define('POWERED_BY_SHOW_TEXT_DESC', '       ');
@define('POWERED_BY_SHOW_IMAGE', '     ');
@define('POWERED_BY_SHOW_IMAGE_DESC', '  ');
@define('PLUGIN_ITEM_DISPLAY', '  ǿ');
@define('PLUGIN_ITEM_DISPLAY_EXTENDED', '  ');
@define('PLUGIN_ITEM_DISPLAY_OVERVIEW', '  ');
@define('PLUGIN_ITEM_DISPLAY_BOTH', ' ');
@define('RSS_IMPORT_CATEGORY', '      ');

@define('COMMENTS_WILL_BE_MODERATED', '       ');
@define('YOU_HAVE_THESE_OPTIONS', '   :');
@define('THIS_COMMENT_NEEDS_REVIEW', ':       ! ! !');
@define('DELETE_COMMENT', ' ');
@define('APPROVE_COMMENT', '  ');
@define('REQUIRES_REVIEW', '  ');
@define('COMMENT_APPROVED', ' #%s    ');
@define('COMMENT_DELETED', '  #%s   ');
@define('COMMENTS_MODERATE', '          ! ! !');
@define('THIS_TRACKBACK_NEEDS_REVIEW', ':        ! ! !');
@define('DELETE_TRACKBACK', '  ');
@define('APPROVE_TRACKBACK', '   ');
@define('TRACKBACK_APPROVED', '  #%s    ');
@define('TRACKBACK_DELETED', '  #%s   ');
@define('VIEW', 'View');
@define('COMMENT_ALREADY_APPROVED', ' #%s     ');
@define('COMMENT_EDITED', '   ');
@define('HIDE', '');
@define('VIEW_EXTENDED_ENTRY', '  "%s"');
@define('TRACKBACK_SPECIFIC_ON_CLICK', 'This link is not meant to be clicked. It contains the trackback URI for this entry. You can use this URI to send ping- & trackbacks from your own blog to this entry. To copy the link, right click and select "Copy Shortcut" in Internet Explorer or "Copy Link Location" in Mozilla.');
@define('PLUGIN_SUPERUSER_HTTPS', 'Use https for login');
@define('PLUGIN_SUPERUSER_HTTPS_DESC', 'Lets the login-link point to a https-location. Your webserver needs to support this!');
@define('INSTALL_SHOW_EXTERNAL_LINKS', '  ɿ');
@define('INSTALL_SHOW_EXTERNAL_LINKS_DESC', '"":           (  -      )           . ""          .          !!');
@define('PAGE_BROWSE_COMMENTS', '  %s  %s,  %s ');
@define('FILTERS', '');
@define('FIND_ENTRIES', '  ');
@define('FIND_COMMENTS', '  ');
@define('FIND_MEDIA', '   ');
@define('FILTER_DIRECTORY', '');
@define('SORT_BY', ' ');
@define('TRACKBACK_COULD_NOT_CONNECT', 'No Trackback sent: Could not open connection to %s on port %d');
@define('MEDIA', ' ');
@define('MEDIA_LIBRARY', '  ');
@define('ADD_MEDIA', '  ');
@define('ENTER_MEDIA_URL', '   :');
@define('ENTER_MEDIA_UPLOAD', '    :');
@define('SAVE_FILE_AS', '  :');
@define('STORE_IN_DIRECTORY', '    : ');
@define('ADD_MEDIA_BLAHBLAH', '<b>     :</b><p>                  !       <a href="http://images.google.com" target="_blank">        </a>                            <p><b>    :</b><br/>');
@define('MEDIA_RENAME', '  ');
@define('IMAGE_RESIZE', '   ');
@define('MEDIA_DELETE', ' ');
@define('FILES_PER_PAGE', '   ');
@define('CLICK_FILE_TO_INSERT', '     :');
@define('SELECT_FILE', '    ');
@define('MEDIA_FULLSIZE', ' ');
@define('CALENDAR_BOW_DESC', '         -  ');
@define('SUPERUSER', ' ');
@define('ALLOWS_YOU_BLAHBLAH', '         ');
@define('CALENDAR', '');
@define('SUPERUSER_OPEN_ADMIN', ' ');
@define('SUPERUSER_OPEN_LOGIN', '  ');
@define('INVERT_SELECTIONS', ' ');
@define('COMMENTS_DELETE_CONFIRM', '      ʿ');
@define('COMMENT_DELETE_CONFIRM', '      #%d,  %s ?');
@define('DELETE_SELECTED_COMMENTS', '  ');
@define('VIEW_COMMENT', ' ');
@define('VIEW_ENTRY', ' ');
@define('DELETE_FILE_FAIL' , '    <b>%s</b>');
@define('DELETE_THUMBNAIL', '     <b>%s</b>');
@define('DELETE_FILE', '   <b>%s</b>');
@define('ABOUT_TO_DELETE_FILE', '     <b>%s</b><br />                 <br />       ݿ<br /><br />');
@define('TRACKBACK_SENDING', '   %s...');
@define('TRACKBACK_SENT', '   ');
@define('TRACKBACK_FAILED', '   %s');
@define('TRACKBACK_NOT_FOUND', '     ');
@define('TRACKBACK_URI_MISMATCH', 'The auto-discovered trackback URI does not match our target URI.');
@define('TRACKBACK_CHECKING', ' <u>%s</u>      ...');
@define('TRACKBACK_NO_DATA', '      ');
@define('TRACKBACK_SIZE', 'Target URI exceeded maximum filesize of %s bytes.');
@define('COMMENTS_VIEWMODE_THREADED', '');
@define('COMMENTS_VIEWMODE_LINEAR', '');
@define('DISPLAY_COMMENTS_AS', '   ');
@define('COMMENTS_FILTER_SHOW', '');
@define('COMMENTS_FILTER_ALL', '');
@define('COMMENTS_FILTER_APPROVED_ONLY', '    ');
@define('COMMENTS_FILTER_NEED_APPROVAL', '    ');
@define('RSS_IMPORT_BODYONLY', 'Put all imported text in the "body" section and do not split up into "extended entry" section.');
@define('SYNDICATION_PLUGIN_FULLFEED', '      RSS');
@define('WEEK', '');
@define('WEEKS', '');
@define('MONTHS', '');
@define('DAYS', '');
@define('ARCHIVE_FREQUENCY', '   ');
@define('ARCHIVE_FREQUENCY_DESC', '        ');
@define('ARCHIVE_COUNT', '    ');
@define('ARCHIVE_COUNT_DESC', '    -  -     ');
@define('BELOW_IS_A_LIST_OF_INSTALLED_PLUGINS', '       ( )   ');
@define('SIDEBAR_PLUGIN', '  ');
@define('EVENT_PLUGIN', '  ');
@define('CLICK_HERE_TO_INSTALL_PLUGIN', '    %s');
@define('VERSION', '');
@define('INSTALL', '  ');
@define('ALREADY_INSTALLED', '    ');
@define('SELECT_A_PLUGIN_TO_ADD', '   -   -  ');
@define('INSTALL_OFFSET', '  ');
@define('STICKY_POSTINGS', ' ');
@define('INSTALL_FETCHLIMIT', '      ');
@define('INSTALL_FETCHLIMIT_DESC', '         ');
@define('IMPORT_ENTRIES', ' ');
@define('EXPORT_ENTRIES', ' ');
@define('IMPORT_WELCOME', '     ');
@define('IMPORT_WHAT_CAN', '              ! ! !');
@define('IMPORT_SELECT', '         !!!');
@define('IMPORT_PLEASE_ENTER', '     ');
@define('IMPORT_NOW', ' !');
@define('IMPORT_STARTING', '   ...');
@define('IMPORT_FAILED', '  ');
@define('IMPORT_DONE', '  ');
@define('IMPORT_WEBLOG_APP', ' ');
@define('IMPORT_NOTES', ':');
@define('EXPORT_FEED', 'Export full RSS feed');
@define('STATUS', '  ');
@define('IMPORT_GENERIC_RSS', 'Generic RSS import');
@define('ACTIVATE_AUTODISCOVERY', '        ');
@define('WELCOME_TO_ADMIN', '       ');
@define('PLEASE_ENTER_CREDENTIALS', '    .');
@define('ADMIN_FOOTER_POWERED_BY', '    %s  PHP %s');
@define('INSTALL_USEGZIP', '    - gzip ');
@define('INSTALL_USEGZIP_DESC', '     .       .        .   ! ! !');
@define('INSTALL_SHOWFUTURE', '  ');
@define('INSTALL_SHOWFUTURE_DESC', '          .           ');
@define('INSTALL_DBPERSISTENT', '  ');
@define('INSTALL_DBPERSISTENT_DESC', '     .     <a href="http://php.net/manual/features.persistent-connections.php" target="_blank">  </a>   ');
@define('NO_IMAGES_FOUND', '    ');
@define('PERSONAL_SETTINGS', ' ');
@define('REFERER', ' ');
@define('NOT_FOUND', '  ');
@define('WRITABLE', ' ');
@define('NOT_WRITABLE', '  ');
@define('PROBLEM_DIAGNOSTIC', '  .             ');
@define('SELECT_INSTALLATION_TYPE', '    ');
@define('WELCOME_TO_INSTALLATION', '      ');
@define('FIRST_WE_TAKE_A_LOOK', '      .       ');
@define('ERRORS_ARE_DISPLAYED_IN', '    %s.   %s   %s');
@define('RED', 'red');
@define('YELLOW', '');
@define('GREEN', '');
@define('PRE_INSTALLATION_REPORT', 'Serendipity v%s pre-installation report');
@define('RECOMMENDED', ' ');
@define('ACTUAL', '');
@define('PHPINI_CONFIGURATION', 'php.ini  ');
@define('PHP_INSTALLATION', 'PHP ');
@define('THEY_DO', ' ');
@define('THEY_DONT', '  ');
@define('SIMPLE_INSTALLATION', ' ');
@define('EXPERT_INSTALLATION', ' ');
@define('COMPLETE_INSTALLATION', '   ');
@define('WONT_INSTALL_DB_AGAIN', '      ');
@define('CHECK_DATABASE_EXISTS', '       ');
@define('CREATING_PRIMARY_AUTHOR', '   \'%s\'');
@define('SETTING_DEFAULT_TEMPLATE', '  ');
@define('INSTALLING_DEFAULT_PLUGINS', '   ');
@define('SERENDIPITY_INSTALLED', '    ');
@define('VISIT_BLOG_HERE', '     ');
@define('THANK_YOU_FOR_CHOOSING', '   ');
@define('ERROR_DETECTED_IN_INSTALL', '     ');
@define('OPERATING_SYSTEM', ' ');
@define('WEBSERVER_SAPI', 'Webserver SAPI');
@define('TEMPLATE_SET', '\'%s\'     ');
@define('SEARCH_ERROR', '      .     .:           .   MySQL      :  <pre>  y_idx  (     ) </pre>       <pre>%s</pre>');
@define('EDIT_THIS_CAT', ' "%s"');
@define('CATEGORY_REMAINING', '          ');
@define('CATEGORY_INDEX', '    :');
@define('NO_CATEGORIES', '   ');
@define('RESET_DATE', 'Reset date');
@define('RESET_DATE_DESC', '       ');
@define('PROBLEM_PERMISSIONS_HOWTO', 'Permissions can be set by running shell command: `<em>%s</em>` on the failed directory, or by setting this using an FTP program');
@define('WARNING_TEMPLATE_DEPRECATED', ':      ! !        ');
@define('ENTRY_PUBLISHED_FUTURE', '      ');
@define('ENTRIES_BY', '  %s');
@define('PREVIOUS', '');
@define('NEXT', '');
@define('APPROVE', '');
@define('DO_MARKUP_DESCRIPTION', '         (,   *, /, _, ...)       HTML    .');
@define('CATEGORY_ALREADY_EXIST', '   "%s"  ');
@define('ERROR_FILE_FORBIDDEN', '        ');
@define('ADMIN', ' ');
@define('ADMIN_FRONTPAGE', ' ');
@define('QUOTE', '');
@define('IFRAME_SAVE', '             XML-RPC        . . .   ');
@define('IFRAME_SAVE_DRAFT', '      ');
@define('IFRAME_PREVIEW', '      ...');
@define('IFRAME_WARNING', '     iframes    _config.inc.php   $serendipity[\'use_iframe\'] variable to FALSE');
@define('NONE', ' ');
@define('USERCONF_CAT_DEFAULT_NEW_ENTRY', '   ');
@define('UPGRADE', '');
@define('UPGRADE_TO_VERSION', '  %s');
@define('DELETE_DIRECTORY', ' ');
@define('DELETE_DIRECTORY_DESC', '           ! ! !          .  ! ! !');
@define('FORCE_DELETE', '          ! ! !');
@define('CREATE_DIRECTORY', ' ');
@define('CREATE_NEW_DIRECTORY', '  ');
@define('CREATE_DIRECTORY_DESC', '       () .           ');
@define('BASE_DIRECTORY', ' ');
@define('USERLEVEL_EDITOR_DESC', '  ');
@define('USERLEVEL_CHIEF_DESC', ' ');
@define('USERLEVEL_ADMIN_DESC', ' ');
@define('USERCONF_USERLEVEL', ' ');
@define('USERCONF_USERLEVEL_DESC', '       ');
@define('USER_SELF_INFO', '   %s (%s)');
@define('ADMIN_ENTRIES', '');
@define('RECHECK_INSTALLATION', '   ');
@define('IMAGICK_EXEC_ERROR', '    "%s", : %s,  : %d');
@define('INSTALL_OFFSET_DESC', '     (   %clock%)     ');
@define('UNMET_REQUIREMENTS', ' : %s');
@define('CHARSET', 'Charset');
@define('AUTOLANG', '    / ');
@define('AUTOLANG_DESC', '                / ');
@define('INSTALL_AUTODETECT_URL', '    (Domain) ');
@define('INSTALL_AUTODETECT_URL_DESC', '   .             .            ()   .         ');
@define('CONVERT_HTMLENTITIES', '    ');
@define('EMPTY_SETTING', '      "%s"!');
@define('USERCONF_REALNAME', ' '); // Translate
@define('USERCONF_REALNAME_DESC', '    .     '); // Translate
@define('HOTLINK_DONE', ' <br />'); // Translate
@define('ENTER_MEDIA_URL_METHOD', '  '); // Translate
@define('ADD_MEDIA_BLAHBLAH_NOTE', ':                     .       .             (    )'); // Translate
@define('MEDIA_HOTLINKED', ' '); // Translate
@define('FETCH_METHOD_IMAGE', '   '); // Translate
@define('FETCH_METHOD_HOTLINK', '   '); // Translate
@define('DELETE_HOTLINK_FILE', '     <b>%s</b>'); // Translate
@define('SYNDICATION_PLUGIN_SHOW_MAIL', '  ');
@define('IMAGE_MORE_INPUT', '  ');
@define('BACKEND_TITLE', '     '); // Translate
@define('BACKEND_TITLE_FOR_NUGGET', '                             HTML Nugget              '); // Translate
@define('CATEGORIES_ALLOW_SELECT', '      ɿ'); // Translate
@define('CATEGORIES_ALLOW_SELECT_DESC', '                              '); // Translate
@define('PAGE_BROWSE_PLUGINS', '  %s  %s,  %s .');
@define('INSTALL_CAT_PERMALINKS', ' ');
@define('INSTALL_CAT_PERMALINKS_DESC', '                   .               %id%                ');
@define('INSTALL_PERMALINK', '   ');
@define('INSTALL_PERMALINK_DESC', 'Here you can define the relative URL structure beginning from your base URL to where entries may become available. You can use the variables %id%, %title%, %day%, %month%, %year% and any other characters.');
@define('INSTALL_PERMALINK_AUTHOR', '     ');
@define('INSTALL_PERMALINK_AUTHOR_DESC', 'Here you can define the relative URL structure beginning from your base URL to where entries from certain authors may become available. You can use the variables %id%, %realname%, %username%, %email% and any other characters.');
@define('INSTALL_PERMALINK_CATEGORY', 'Permalink Category URL structure');
@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Here you can define the relative URL structure beginning from your base URL to where entries from certain categories may become available. You can use the variables %id%, %name%, %parentname%, %description% and any other characters.');
@define('INSTALL_PERMALINK_FEEDCATEGORY', 'Permalink RSS-Feed Category URL structure');
@define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Here you can define the relative URL structure beginning from your base URL to where RSS-feeds from certain categories may become available. You can use the variables %id%, %name%, %description% and any other characters.');
@define('INSTALL_PERMALINK_FEEDAUTHOR', 'Permalink RSS-Feed Author URL structure');
@define('INSTALL_PERMALINK_FEEDAUTHOR_DESC', 'Here you can define the relative URL structure beginning from your base URL to where RSS-feeds from specific users may be viewed. You can use the variables %id%, %realname%, %username%, %email% and any other characters.');
@define('INSTALL_PERMALINK_ARCHIVESPATH', ' ');
@define('INSTALL_PERMALINK_ARCHIVEPATH', ' ');
@define('INSTALL_PERMALINK_CATEGORIESPATH', ' ');
@define('INSTALL_PERMALINK_AUTHORSPATH', '   ');
@define('INSTALL_PERMALINK_UNSUBSCRIBEPATH', '   ');
@define('INSTALL_PERMALINK_DELETEPATH', '  ');
@define('INSTALL_PERMALINK_APPROVEPATH', '     ');
@define('INSTALL_PERMALINK_FEEDSPATH', ' RSS');
@define('INSTALL_PERMALINK_PLUGINPATH', '   ');
@define('INSTALL_PERMALINK_ADMINPATH', '  ');
@define('INSTALL_PERMALINK_SEARCHPATH', ' ');
@define('INSTALL_CAL', ' ');
@define('INSTALL_CAL_DESC', '    ');
@define('REPLY', '');
@define('USERCONF_GROUPS', ' ');
@define('USERCONF_GROUPS_DESC', '      .      ');
@define('MANAGE_GROUPS', ' ');
@define('DELETED_GROUP', '  #%d %s ');
@define('CREATED_GROUP', '  %s  ');
@define('MODIFIED_GROUP', '  %s  ');
@define('GROUP', '');
@define('CREATE_NEW_GROUP', '  ');
@define('DELETE_GROUP', '       #%d %s');
@define('USERLEVEL_OBSOLETE', ':         .         ! ! ! ');
@define('SYNDICATION_PLUGIN_FEEDBURNERID', 'FeedBurner ID');
@define('SYNDICATION_PLUGIN_FEEDBURNERID_DESC', 'The ID of the feed you wish to publish');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG', 'FeedBurner image');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG_DESC', 'Name of image to display (or leave blank for counter), located on feedburner.com, ex: fbapix.gif');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE', 'FeedBurner title');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE_DESC', 'Title (if any) to display alongside the image');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT', 'FeedBurner image text');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT_DESC', 'Text (if any) to display when hovering the image');
@define('INSTALL_DBPORT', '  ');
@define('INSTALL_DBPORT_DESC', '    ');
@define('PLUGIN_GROUP_FRONTEND_EXTERNAL_SERVICES', '   ');
@define('PLUGIN_GROUP_FRONTEND_FEATURES', ' ');
@define('PLUGIN_GROUP_FRONTEND_FULL_MODS', 'Frontend: Full Mods');
@define('PLUGIN_GROUP_FRONTEND_VIEWS', 'Frontend: ');
@define('PLUGIN_GROUP_FRONTEND_ENTRY_RELATED', 'Frontend: Entry Related');
@define('PLUGIN_GROUP_BACKEND_EDITOR', 'Backend: ');
@define('PLUGIN_GROUP_BACKEND_USERMANAGEMENT', 'Backend: Usermanagement');
@define('PLUGIN_GROUP_BACKEND_METAINFORMATION', 'Backend: Meta information');
@define('PLUGIN_GROUP_BACKEND_TEMPLATES', 'Backend: ');
@define('PLUGIN_GROUP_BACKEND_FEATURES', 'Backend: ');
@define('PLUGIN_GROUP_IMAGES', '');
@define('PLUGIN_GROUP_ANTISPAM', ' ');
@define('PLUGIN_GROUP_MARKUP', ' ');
@define('PLUGIN_GROUP_STATISTICS', '');
@define('PERMISSION_PERSONALCONFIGURATION', 'personalConfiguration: Access personal configuration');
@define('PERMISSION_PERSONALCONFIGURATIONUSERLEVEL', 'personalConfigurationUserlevel: Change userlevels');
@define('PERMISSION_PERSONALCONFIGURATIONNOCREATE', 'personalConfigurationNoCreate: Change "forbid creating entries"');  
@define('PERMISSION_PERSONALCONFIGURATIONRIGHTPUBLISH', 'personalConfigurationRightPublish: Change right to publish entries');
@define('PERMISSION_SITECONFIGURATION', 'siteConfiguration: Access system configuration');
@define('PERMISSION_BLOGCONFIGURATION', 'blogConfiguration: Access blog-centric configuration');
@define('PERMISSION_ADMINENTRIES', 'adminEntries: Administrate entries');
@define('PERMISSION_ADMINENTRIESMAINTAINOTHERS', 'adminEntriesMaintainOthers: Administrate other user\'s entries');
@define('PERMISSION_ADMINIMPORT', 'adminImport: Import entries');
@define('PERMISSION_ADMINCATEGORIES', 'adminCategories: Administrate categories');
@define('PERMISSION_ADMINCATEGORIESMAINTAINOTHERS', 'adminCategoriesMaintainOthers: Administrate other user\'s categories');
@define('PERMISSION_ADMINCATEGORIESDELETE', 'adminCategoriesDelete: Delete categories');
@define('PERMISSION_ADMINUSERS', 'adminUsers: Administrate users');
@define('PERMISSION_ADMINUSERSDELETE', 'adminUsersDelete: Delete users');
@define('PERMISSION_ADMINUSERSEDITUSERLEVEL', 'adminUsersEditUserlevel: Change userlevel');
@define('PERMISSION_ADMINUSERSMAINTAINSAME', 'adminUsersMaintainSame: Administrate users that are in your group(s)');
@define('PERMISSION_ADMINUSERSMAINTAINOTHERS', 'adminUsersMaintainOthers: Administrate users that are not in your group(s)');
@define('PERMISSION_ADMINUSERSCREATENEW', 'adminUsersCreateNew:   ');
@define('PERMISSION_ADMINUSERSGROUPS', 'adminUsersGroups: Administrate usergroups');
@define('PERMISSION_ADMINPLUGINS', 'adminPlugins: Administrate plugins');
@define('PERMISSION_ADMINPLUGINSMAINTAINOTHERS', 'adminPluginsMaintainOthers: Administrate other user\'s plugins');
@define('PERMISSION_ADMINIMAGES', 'adminImages: Administrate media files');
@define('PERMISSION_ADMINIMAGESDIRECTORIES', 'adminImagesDirectories: Administrate media directories');
@define('PERMISSION_ADMINIMAGESADD', 'adminImagesAdd: Add new media files');
@define('PERMISSION_ADMINIMAGESDELETE', 'adminImagesDelete: Delete media files');
@define('PERMISSION_ADMINIMAGESMAINTAINOTHERS', 'adminImagesMaintainOthers: Administrate other user\'s media files');
@define('PERMISSION_ADMINIMAGESVIEW', 'adminImagesView: View media files');
@define('PERMISSION_ADMINIMAGESSYNC', 'adminImagesSync: Sync thumbnails');
@define('PERMISSION_ADMINCOMMENTS', 'adminComments: Administrate comments');
@define('PERMISSION_ADMINTEMPLATES', 'adminTemplates: Administrate templates');
@define('INSTALL_BLOG_EMAIL', '  ');
@define('INSTALL_BLOG_EMAIL_DESC', '               .                                     ');
@define('CATEGORIES_PARENT_BASE', '    ');
@define('CATEGORIES_PARENT_BASE_DESC', 'You can choose a parent category so that only the child categories are shown.');
@define('CATEGORIES_HIDE_PARALLEL', '       ');
@define('CATEGORIES_HIDE_PARALLEL_DESC', 'If you want to hide categories that are part of a different category tree, you need to enable this. This feature makes most sense if used in conjunction with a multi-blog using the "Properties/Templates of categories" plugin.');
@define('PERMISSION_ADMINIMAGESVIEWOTHERS', 'adminImagesViewOthers: View other user\'s media files');
@define('CHARSET_NATIVE', '');
@define('INSTALL_CHARSET', ' ');
@define('INSTALL_CHARSET_DESC', '          UTF-8       (ISO, EUC, ...)         UTF-8                 UTF-8  .  . . . . . .  . . .           .           .     http://www.s9y.org/index.php?node=46       ');
@define('CALENDAR_ENABLE_EXTERNAL_EVENTS', 'Enable Plugin API hook');
@define('CALENDAR_EXTEVENT_DESC', 'If enabled, plugins can hook into the calendar to display their own events highlighted. Only enable if you have installed plugins that need this, otherwise it just decreases performance.');
@define('XMLRPC_NO_LONGER_BUNDLED', 'The XML-RPC API Interface to Serendipity is no longer bundled because of ongoing security issues with this API and not many people using it. Thus you need to install the XML-RPC Plugin to use the XML-RPC API. The URL to use in your applications will NOT change - as soon as you have installed the plugin, you will again be able to use the API.');
@define('PERM_READ', ' ');
@define('PERM_WRITE', ' ');

@define('PERM_DENIED', ' ');
@define('INSTALL_ACL', '    ');
@define('INSTALL_ACL_DESC', 'If enabled, the usergroup permission settings you setup for categories will be applied when logged-in users view your blog. If disabled, the read-permissions of the categories are NOT applied, but the positive effect is a little speedup on your blog. So if you don\'t need multi-user read permissions for your blog, disable this setting.');
@define('PLUGIN_API_VALIDATE_ERROR', '    "%s".     "%s".');
@define('USERCONF_CHECK_PASSWORD', '  ');
@define('USERCONF_CHECK_PASSWORD_DESC', '                 ');
@define('USERCONF_CHECK_PASSWORD_ERROR', '      .         . ! ! ! :    ');
@define('ERROR_XSRF', 'Your browser did not sent a valid HTTP-Referrer string. This may have either been caused by a misconfigured browser/proxy or by a Cross Site Request Forgery (XSRF) aimed at you. The action you requested could not be completed.');
@define('AUTHORS', '');
@define('AUTHORS_ALLOW_SELECT', '      ɿ');
@define('AUTHORS_ALLOW_SELECT_DESC', 'If this option is enabled, a checkbox will be put next to each author in this sidebar plugin.  Users can check those boxes and see entries matching their selection.');
@define('AUTHOR_PLUGIN_DESC', '   ');
@define('CATEGORY_PLUGIN_TEMPLATE', 'Enable Smarty-Templates?');
@define('CATEGORY_PLUGIN_TEMPLATE_DESC', 'If this option is enabled, the plugin will utilize Smarty-Templating features to output the category listing. If you enable this, you can change the layout via the "plugin_categories.tpl" template file. Enabling this option will impact performance, so if you do not need to make customizations, leave it disabled.');
@define('CATEGORY_PLUGIN_SHOWCOUNT', '    ݿ');
@define('AUTHORS_SHOW_ARTICLE_COUNT', '     ');
@define('AUTHORS_SHOW_ARTICLE_COUNT_DESC', '               ');
@define('INSTALL_PERMALINK_COMMENTSPATH', 'Path to comments');
@define('PERM_SET_CHILD', 'Set the same permissions on all child directories');
@define('PERMISSION_FORBIDDEN_PLUGINS', 'Forbidden plugins');
@define('PERMISSION_FORBIDDEN_HOOKS', 'Forbidden events');
@define('PERMISSION_FORBIDDEN_ENABLE', 'Enable Plugin ACL for usergroups?');
@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'If the option "Plugin ACL for usergroups" is enabled in the configuration, you can specify which usergroups are allowed to execute certain plugins/events.');
@define('DELETE_SELECTED_ENTRIES', 'Delete selected entries');
@define('PLUGIN_AUTHORS_MINCOUNT', 'Show only authors with at least X articles');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
@define('IMPORT_WP_PAGES', 'Also fetch attachments and staticpages as normal blog entries?');
@define('USERCONF_CREATE', 'Disable user / forbid activity?');
@define('USERCONF_CREATE_DESC', 'If selected, the user will not have any editing or creation possibilities on the blog anymore. When logging in to the backend, he cannot do anything else apart from logging out and viewing his personal configuration.');
@define('CATEGORY_HIDE_SUB', 'Hide postings made to sub-categories?');
@define('CATEGORY_HIDE_SUB_DESC', 'By default, when you browse a category also entries of any subcategory are displayed. If this option is turned on, only postings of the currently selected category are displayed.');
@define('PINGBACK_SENDING', 'Sending pingback to URI %s...');
@define('PINGBACK_SENT', 'Pingback successful');
@define('PINGBACK_FAILED', 'Pingback failed: %s');
@define('PINGBACK_NOT_FOUND', 'No pingback-URI found.');
@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
@define('SET_TO_MODERATED', 'Moderate');
@define('COMMENT_MODERATED', 'Comment #%s has successfully been set as moderated');
@define('CENTER', 'center');
@define('FULL_COMMENT_TEXT', 'Yes, with full comment text');

@define('COMMENT_TOKENS', 'Use Tokens for Comment Moderation?');
@define('COMMENT_TOKENS_DESC', 'If tokens are used, comments can be approved and deleted by clicking the email links without requiring login access to the blog. Note that this is a convenience feature, and if your mails get hijacked, those people can approve/delete the referenced comment without further authentication.');
@define('COMMENT_NOTOKENMATCH', 'Moderation link has expired or comment #%s has already been approved or deleted');
@define('TRACKBACK_NOTOKENMATCH', 'Moderation link has expired or trackback #%s has already been approved or deleted');
@define('BADTOKEN', 'Invalid Moderation Link'); 

@define('CONFIRMATION_MAIL_ALWAYS', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n");
@define('CONFIRMATION_MAIL_ONCE', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled one-time mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n\nAfter you have done that, you can always post comments on that blog with your username and e-mail address without receiving such notifications.");
@define('INSTALL_SUBSCRIBE_OPTIN', 'Use Double-Opt In for comment subscriptions?');
@define('INSTALL_SUBSCRIBE_OPTIN_DESC', 'If enabled, when a comment is made where the person wants to be notified via e-mail about new comments to the same entry, he must confirm his subscription to the entry. This Double-Opt In is required by german law, for example.');
@define('CONFIRMATION_MAIL_SUBSCRIPTION', "Hello %s,\n\nYou have requested to be notified for comments to \"%s\" (<%s>). To approve this subscription (\"Double Opt In\") please click this link:\n<%s>\n.");
@define('NOTIFICATION_CONFIRM_SUBMAIL', 'Your confirmation of your comment subscription has been successfully entered.');
@define('NOTIFICATION_CONFIRM_MAIL', 'Your confirmation of the comment has been successfully entered.');
@define('NOTIFICATION_CONFIRM_SUBMAIL_FAIL', 'Your comment subscription could not be confirmed. Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must request a new confirmation mail.');
@define('NOTIFICATION_CONFIRM_MAIL_FAIL', 'Your comment confirmation could not be confirmed.  Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must send your comment again.');
@define('PLUGIN_DOCUMENTATION', 'Documentation');
@define('PLUGIN_DOCUMENTATION_LOCAL', 'Local Documentation');
@define('PLUGIN_DOCUMENTATION_CHANGELOG', 'Version history');
@define('SYNDICATION_PLUGIN_BIGIMG', 'Big Image');
@define('SYNDICATION_PLUGIN_BIGIMG_DESC', 'Display a (big) image at the top of the feeds in sidebar, enter full or absolute URL to image file.');
@define('SYNDICATION_PLUGIN_FEEDNAME', 'Displayed name for "feed"');
@define('SYNDICATION_PLUGIN_FEEDNAME_DESC', 'Enter an optional custom name for the feeds (defaults to "feed" when empty)');
@define('SYNDICATION_PLUGIN_COMMENTNAME', 'Displayed name for "comment" feed');
@define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', 'Enter an optional custom name for the comment feed');
